@@ -769,16 +769,24 @@ class pluginclass(object):
                             i.hide()
                         else:
                             shownList.append(i)
-                            #if this is the first matching item
-                            #focus it
-                            if(not showns):
-                                i.grab_focus()
+                            self.applicationsBox.remove(i)
                             showns = True
                 if not showns:
                     if len(text) >= 3:
                         self.add_search_suggestions(text)
                         if self.useAPT:
                             GLib.timeout_add(300, self.add_apt_filter_results, text)
+                else:
+                    # Sort applications by relevance, and alphabetical within that
+                    shownList = sorted(shownList, key=lambda app: app.appName)
+                    shownList = sorted(shownList, key=lambda app: app.relevance, reverse=True)
+                    focused = False
+                    for i in shownList:
+                        self.applicationsBox.add(i)
+                        if not focused:
+                            # Grab focus of the first app shown
+                            i.grab_focus()
+                            focused = True
                 for i in self.categoriesBox.get_children():
                     i.released()
                     i.set_relief(Gtk.ReliefStyle.NONE)
